pub struct RelativeStrengthIndex {
pub period: usize,
pub ma_type: MovingAverageType,
pub value: f64,
pub count: usize,
pub initialized: bool,
/* private fields */
}Expand description
An indicator which calculates a relative strength index (RSI) across a rolling window.
Fields
period: usizema_type: MovingAverageTypevalue: f64count: usizeinitialized: boolImplementations
Sourceimpl RelativeStrengthIndex
impl RelativeStrengthIndex
Sourcepub fn new(period: usize, ma_type: Option<MovingAverageType>) -> Self
pub fn new(period: usize, ma_type: Option<MovingAverageType>) -> Self
Creates a new RelativeStrengthIndex instance.
pub fn update_raw(&mut self, value: f64)
Sourceimpl RelativeStrengthIndex
impl RelativeStrengthIndex
Sourcepub fn py_new(period: usize, ma_type: Option<MovingAverageType>) -> Self
pub fn py_new(period: usize, ma_type: Option<MovingAverageType>) -> Self
An indicator which calculates a relative strength index (RSI) across a rolling window.